@@ -20,6 +20,7 @@ class Matrix(BaseModel):
     tactic_refs: List[Id] = field()
     created_by_ref: Id = field()
     description: AnyStr = field()
+    revoked: bool = field(factory=bool)
     x_mitre_domains: List[MitreDomain] = field(factory=list)
     object_marking_refs: List[Id] = field(factory=list)
     external_references: List[ExternalReferences] = field(factory=list)
@@ -31,3 +32,16 @@ class Matrix(BaseModel):
     x_mitre_version: SemVersion = field(factory=SemVersion)
     x_mitre_modified_by_ref: Id = field(factory=Id)
     x_mitre_attack_spec_version: SemVersion = field(factory=SemVersion)
+
+    def __init__(self, **kwargs):
+        try:
+            self.__attrs_init__(**kwargs)
+        except TypeError as te:
+            raise te
+
+    def __attrs_post_init__(self):
+        if self.external_references:
+            return_list = []
+            for item in self.external_references:
+                return_list.append(ExternalReferences(**item))
+            self.external_references = return_list
